@@ -29,7 +29,7 @@ def read(path):
     return json.loads(open(path, encoding="utf-8").read())
 
 
-def load_cached(path):
+def load_cached(path, url=setting.UA_CACHE_URL):
     if not os.path.exists(path):
-        update(path, get(setting.CACHE_URL).text)
+        update(path, get(url).text)
     return read(path)
